@@ -8,9 +8,7 @@ from collections import Counter
 import string, nltk
 from nltk.corpus import stopwords
 import urllib.request, json
-nltk.download('wordnet')
-nltk.download('punkt')
-nltk.download('stopwords')
+
 
 
 def process_message(message):
@@ -52,14 +50,13 @@ class EmoTFIDF:
     """Lexicon source is (C) 2016 National Research Council Canada (NRC) and library is for research purposes only.  Source: http://sentiment.nrc.ca/lexicons-for-research/"""
 
     with urllib.request.urlopen("https://raw.githubusercontent.com/mmsa/EmoTFIDF/main/emotions_lex.json") as url:
-        data = json.loads(url.read().decode())
+        lexicon = json.loads(url.read().decode())
 
     def set_text(self, text):
         self.text = process_message(text)
         self.words = list(nltk.word_tokenize(self.text))
         self.sentences = list(nltk.sent_tokenize(self.text))
         get_emotions(self)
-        top_emotions(self)
 
     def computeTFIDF(self, docs):
         vectorizer = TfidfVectorizer(max_features=200, stop_words=stopwords.words('english'),
